@@ -35,9 +35,18 @@ public:
     //get/set show header
     bool isShowRemain() const;
     void setShowRemain(const bool &aShow) const;
-    //get/set show header
-    bool isStdOnly() const;
-    void setStdOnly(const bool &aShow) const;
+    //get/set Alarm Filter
+    int alarmFilter() const;
+    void setAlarmFilter(const int &aFilter) const;
+    //get/set show empty
+    bool isShowEmpty() const;
+    void setShowEmpty(const bool &aShow) const;
+    //get/set show recurrent
+    bool isShowRecurrent() const;
+    void setShowRecurrent(const bool &aShow) const;
+    //get/set time frame
+    int timeFrame() const;
+    void setTimeFrame(const int &aFrame) const;
 
 
 private:
