@@ -17,11 +17,11 @@
 #define alarmIconPath "/usr/share/icons/hicolor/48x48/hildon/general_alarm_on.png"
 #define clockIconPath "/usr/share/icons/hicolor/48x48/hildon/general_clock.png"
 #define recurIconPath "/usr/share/icons/hicolor/48x48/hildon/general_refresh.png"
+#define calendarIconPath "/usr/share/icons/hicolor/48x48/hildon/general_calendar.png"
+#define eventIconPath "/usr/share/icons/hicolor/48x48/hildon/general_profile.png"
 
 static int FNT_ADD = 3;
-//static int iconWidth = 30;
-static int NEXT_PERIOD = 86400; // look forward for 24 hours
-static QString STD_ALARM_ID("worldclock_alarmd_id");
+//static int NEXT_PERIOD = 86400; // look forward for 24 hours
 
 AlarmWindow::AlarmWindow(QWidget *parent) :
     QWidget(parent),
@@ -49,6 +49,8 @@ void AlarmWindow::fillAlarmList()
 #if  defined(Q_WS_MAEMO_5)
     QIcon icn (alarmIconPath);
     QIcon icnRecur (recurIconPath);
+    QIcon icnEvent (eventIconPath);
+    QIcon icnCalendar (calendarIconPath);
 #else
     QIcon icn ("d:\\Qt\\Project\\NextAlarm\\hicolor\\18x18\\hildon\\general_alarm_on.png");
 #endif
@@ -60,7 +62,7 @@ void AlarmWindow::fillAlarmList()
     if (m_showCaption)
     {
        QString header;
-       header = QString(tr("alarms in next %1 h").arg(QString::number(86400/3600)));
+       header = QString(tr("alarms in next %1 h").arg(QString::number(m_timeFrame)));
        QListWidgetItem * item = new QListWidgetItem;
        item->setText(header);
        item->setTextAlignment(Qt::AlignBottom);
@@ -77,8 +79,11 @@ void AlarmWindow::fillAlarmList()
     cookie_t *list, *iter;
     time_t now;
 
+    //TODO remove this
+//    m_timeFrame = 96;
+
     now = time(NULL);
-    list = alarmd_event_query(now, now + NEXT_PERIOD, ALARM_EVENT_DISABLED, 0, NULL);
+    list = alarmd_event_query(now, now + m_timeFrame*3600, ALARM_EVENT_DISABLED, 0, NULL);
     if (list == NULL) {
             fprintf(stderr, "alarm_event_query() failed\n");
     }
@@ -94,65 +99,107 @@ void AlarmWindow::fillAlarmList()
 
                 alarm_event_t * aevent = alarmd_event_get (*iter);
 
-/*                    if (QString::fromUtf8(aevent->alarm_appid) == QString("Enter_name"))
+                int action_cnt = aevent->action_cnt;
+                int recur = alarm_event_is_recurring (aevent);
+                if (((m_alarmFilter == 2) || ((m_alarmFilter == 1) && (action_cnt > 1)) || ((m_alarmFilter == 0) && (action_cnt == 2)))
+                    && ((m_showRecurrent) || ((!m_showRecurrent) && (!recur))))
                 {
-                    qDebug() << "error alarm found";
-                    alarmd_event_del(*iter);
-                }
-*/
-                if ((!m_showStdOnly) || ((m_showStdOnly) && (QString::fromUtf8(aevent->alarm_appid) == STD_ALARM_ID)))
-                {
-//                        qDebug() << "real alarm found";
-  //                  }
 
-                    int recur = alarm_event_is_recurring (aevent);
+
                     bool toAdd = false;
-                    time_t ttime;
-                    if (recur > 0)
+                    time_t ttime = alarm_event_get_trigger(aevent);
+                    if (recur > 0) // find recurrent alarms
                     {
                         if (aevent->recurrence_cnt > 0)
                         {
                             toAdd = true;
-                            alarm_recur_t* arecur = &aevent->recurrence_tab[0];
-                            const char* tz = alarm_event_get_alarm_tz(aevent);
-                            struct tm* rtm = localtime(&now);
-                            ttime = alarm_recur_next(arecur,rtm,tz);
+//                            alarm_recur_t* arecur = &aevent->recurrence_tab[0];
+  //                          const char* tz = alarm_event_get_alarm_tz(aevent);
+    //                        struct tm* rtm = localtime(&now);
+      //                      ttime = alarm_recur_next(arecur,rtm,tz);
                             item->setIcon(icnRecur);
                         }
                     }
-                    else
+                    else // simple alarms
                     {
                         toAdd = true;
-                        struct tm* rtm = localtime(&now);
-                        struct tm atm;
-                        alarm_event_get_time (aevent,&atm);
-                        rtm->tm_hour = atm.tm_hour;
-                        rtm->tm_min = atm.tm_min;
-                        ttime = mktime(rtm);
+        //                struct tm* rtm = localtime(&now);
+          //              struct tm atm;
+            //            alarm_event_get_time (aevent,&atm);
+              //          rtm->tm_hour = atm.tm_hour;
+                //        rtm->tm_min = atm.tm_min;
+                  //      ttime = mktime(rtm);
                         item->setIcon(icn);
                     }
-                    if (toAdd)
+
+                    if (action_cnt == 1)
+                        item->setIcon(icnEvent);
+                    if (action_cnt == 3)
+                        item->setIcon(icnCalendar);
+
+                    if (toAdd) // preparing display string
                     {
                         aFound = true;
-                        const char * cTitle = alarm_event_get_message(aevent);
-                        QString aTitle (QString::fromUtf8(cTitle));
+
                         QDateTime qdtm = QDateTime::fromTime_t(ttime);
                         QTime qtm = qdtm.time();
-                        QString sTime = qtm.toString(Qt::DefaultLocaleShortDate);
-                        if (m_showRemain) // calc remaining time
+                        int days = 0;
+                        QDateTime currDate;
+                        if (m_timeFrame > 24) // time can be more then one day
                         {
-                            QTime currTime = QTime::currentTime();
-                            int remain = currTime.secsTo(qtm);
-                            if (remain < 0) remain += 86400;
-                            int h = remain/3600;
-                            int m = (remain - h*3600)/60;
-                            QTime remTime(h,m);
-                            QString sRemTime = " > " + remTime.toString("H:mm");
-                            sTime += sRemTime;
+                            currDate = QDateTime::currentDateTime();
+                            days = currDate.daysTo(qdtm);
                         }
 
-                        if ((!aTitle.isEmpty()) && m_showTitle ) // show title of alarm
-                            sTime += " : \"" + aTitle + "\"";
+                        QString sTime;
+
+                        sTime = qtm.toString(Qt::DefaultLocaleShortDate);
+                        if ((days > 0) || (m_showRemain))
+                            sTime += " (";
+                        if (days > 0) // calc for more than 1 day alarms
+                        {
+                            sTime += QString::number(days) + tr("d");
+                            if (m_showRemain)
+                                sTime += " ";
+//                            QDate qdt = qdtm.date();
+  //                          sTimeDay = qdt.toString(Qt::DefaultLocaleLongDate);
+                        }
+//                        else
+  //                      {
+
+                            if (m_showRemain) // calc remaining time
+                            {
+                                QTime currTime = QTime::currentTime();
+                                int remain = currTime.secsTo(qtm);
+                                if (remain < 0) remain += 86400;
+                                int h = remain/3600;
+                                int m = (remain - h*3600)/60;
+                                QTime remTime(h,m);
+//                                QString sRemTime =
+                                sTime += remTime.toString("H:mm");
+                            }
+             //           }
+                        if ((days > 0) || (m_showRemain))
+                            sTime += ")";
+
+                        if (m_showTitle) // show title of alarm
+                        {
+                            QString aTitle;
+                            const char * cTitle = alarm_event_get_message(aevent);
+                            aTitle = QString::fromUtf8(cTitle);
+                            if (aTitle.isEmpty())
+                            {
+                                cTitle = alarm_event_get_title(aevent);
+                                aTitle = QString::fromUtf8(cTitle);
+                                if (aTitle.isEmpty())
+                                {
+                                    cTitle = alarm_event_get_alarm_appid(aevent);
+                                    aTitle = QString::fromUtf8(cTitle);
+                                }
+                            }
+                            if (!aTitle.isEmpty())
+                                sTime += ": " + aTitle;
+                        }
                         item->setText(sTime);
                         ui->listWidget->addItem(item);
                     }
@@ -162,13 +209,18 @@ void AlarmWindow::fillAlarmList()
     free(list);
     if (!aFound) // now alarms
     {
-        QListWidgetItem * item = new QListWidgetItem;
-        item->setSizeHint(QSize (m_width-fntHeight,fntHeight));
-        item->setForeground(m_color);
-        item->setFont(m_font);
-//        item->setText(tr("no active alarms"));
-        item->setText(tr("--:--"));
-        ui->listWidget->addItem(item);
+        if (m_showIfEmpty)
+        {
+            QListWidgetItem * item = new QListWidgetItem;
+            item->setSizeHint(QSize (m_width-fntHeight,fntHeight));
+            item->setForeground(m_color);
+            item->setFont(m_font);
+    //        item->setText(tr("no active alarms"));
+            item->setText(tr("--:--"));
+            ui->listWidget->addItem(item);
+        }
+        else
+            ui->listWidget->clear();
     }
 #else
     for (int i = 0; i < 5; i++)
@@ -225,7 +277,12 @@ void AlarmWindow::loadSettings()
     m_showCaption = nalarmsettings::getInstance().isShowHeader();
     m_showRemain = nalarmsettings::getInstance().isShowRemain();
     m_showTitle = nalarmsettings::getInstance().isShowTitle();
-    m_showStdOnly = nalarmsettings::getInstance().isStdOnly();
+//    m_showStdOnly = nalarmsettings::getInstance().isStdOnly();
+
+    m_showRecurrent = nalarmsettings::getInstance().isShowRecurrent();
+    m_showIfEmpty = nalarmsettings::getInstance().isShowEmpty();
+    m_alarmFilter = nalarmsettings::getInstance().alarmFilter();
+    m_timeFrame = nalarmsettings::getInstance().timeFrame();
 }
 
 void AlarmWindow::homeScreenChanged(bool isOnCurrentHomescreen)
